@@ -5,11 +5,11 @@ use POSIX qw(WNOHANG);
 use Log::Log4perl qw(:easy);
 
 use constant DEFAULT_ERROR_TIMEOUT => 10;
-use constant DEFAULT_MAXPROCS      => 1;
+use constant DEFAULT_WORKERS       => 1;
 use constant DEFAULT_REAP_TIMEOUT  => .1;
-use constant DEFAULT_TOTALPROCS    => 1;
+use constant DEFAULT_WORKER_TOTAL  => 1;
 
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 =head1 NAME
 
@@ -25,8 +25,8 @@ Provides a very simple, no frills fork manager.
 
     my $forker = Parallel::Tiny->new(
         handler    => $obj,
-        maxprocs   => 4,
-        totalprocs => 'infinite',
+        workers   => 4,
+        worker_total => 'infinite',
     );
 
     $forker->run();
@@ -44,27 +44,30 @@ takes arguments as a hash or hashref with the following arguments:
   handler - an object you provide which has a run() method
             (required)
 
-  maxprocs - the number of simoltaneous forked processes you
-             want to allow at one time
-             (default 1)
+  workers - the number of simoltaneous forked processes you
+            want to allow at one time
+            (default 1)
 
-  totalprocs - the total number of processes that you want to run
-               (default 1)
+  worker_total - the total number of processes that you want to run
+            (default 1)
 
   reap_timeout - the number of seconds to wait between runs of
-                 waitpid() to reap children
-                 (default .1)
+            waitpid() to reap children
+            (default .1)
+
+  kill_all - When the parent gets TERM, kill all child processes immediately.
+            (default 0)
 
 You can for instance, say that you want to run 100 proccesses,
 but only 4 at a time like this:
 
     my $forker = Parallel::Tiny->new(
         handler => $obj,
-        maxprocs => 4,
-        totalprocs => 100,
+        workers => 4,
+        worker_total => 100,
     );
 
-If you want you can provide 'infinite' for totalprocs.
+If you want you can provide 'infinite' for worker_total.
 If you do this, you're responsible for stopping the fork manager!
 
 =cut
@@ -79,21 +82,21 @@ sub new {
     die 'handler does not implement a run() function'     unless $handler->can('run');
 
     # set some defaults
-    $args->{maxprocs}     ||= DEFAULT_MAXPROCS;
+    $args->{workers}      ||= DEFAULT_WORKERS;
     $args->{reap_timeout} ||= DEFAULT_REAP_TIMEOUT;
-    $args->{totalprocs}   ||= DEFAULT_TOTALPROCS;
+    $args->{worker_total} ||= DEFAULT_WORKER_TOTAL;
     $args->{kill_all}     ||= 0;
 
     # special configuration
-    undef $args->{totalprocs} if $args->{totalprocs} eq 'infinite';
+    undef $args->{worker_total} if $args->{worker_total} eq 'infinite';
 
     return bless({
             _continue     => 1,
             _handler      => $handler,
             _jobs         => {},
-            _maxprocs     => $args->{maxprocs},
+            _workers     => $args->{workers},
             _reap_timeout => $args->{reap_timeout},
-            _totalprocs   => $args->{totalprocs},
+            _worker_total   => $args->{worker_total},
             _kill_all     => $args->{kill_all},
     }, $class);
 }
@@ -122,7 +125,7 @@ sub run {
         # parent work
         my $pid = fork();
         if ($pid) {
-            $self->{_totalprocs}-- if defined $self->{_totalprocs} and $self->{_totalprocs} > 0;
+            $self->{_worker_total}-- if defined $self->{_worker_total} and $self->{_worker_total} > 0;
             $self->{_jobs}{$pid} = 1;
             next;
         }
@@ -155,10 +158,10 @@ sub waitqueue {
 
     # check for any stopping conditions
     return 0 unless $self->{_continue};
-    return 0 if defined $self->{_totalprocs} and $self->{_totalprocs} <= 0;
+    return 0 if defined $self->{_worker_total} and $self->{_worker_total} <= 0;
 
     # wait to reap at least one child
-    while (keys(%{ $self->{_jobs} }) >= $self->{_maxprocs}) {
+    while (keys(%{ $self->{_jobs} }) >= $self->{_workers}) {
         $self->_reapchildren();
         sleep $self->{_reap_timeout};
     }
